"""
Tools module for Elasticsearch MCP.
Contains helper functions for tools.
"""
from .connections import do_list_connections, do_get_connection
from .setup import run_setup, do_check_setup_status

__all__ = [
    "do_list_connections",
    "do_get_connection",
    "run_setup",
    "do_check_setup_status",
]
